/*
smd2csm.cpp - example of .smd -> .csm conversion
Copyright (C) 2024 Uncle Mike

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
*/

#include <stdio.h>
#include <string.h>
#include <minmax.h>
#include "math.h"
#include "model_csm.h"
#include "model_smd.h"

int main( int argc, char **argv )
{
	if( argc <= 1 )
	{
		printf( "no inputfile specified\n" );
		system( "pause" );
	}
	else if( argc == 2 )
	{
		char	outname[CSM_MAXNAME];

		strncpy( outname, argv[1], sizeof( outname ) - 1 );

		if( !stricmp( GetExtension( argv[1] ), "smd" ))
		{
			model_smd_t	smd;
			model_t*		csm;

			// smd->csm
			if(( csm = smd.load( argv[1] )) != NULL )
			{
				ReplaceExtension( outname, ".csm", sizeof( outname ));
				csm->save( outname );
				delete csm;
			}
		}
		else if( !stricmp( GetExtension( argv[1] ), "csm" ))
		{
			model_smd_t	smd;
			model_t		csm;

			// smd->csm
			if( csm.load( argv[1] ))
			{
				ReplaceExtension( outname, ".smd", sizeof( outname ));
				smd.save( outname, &csm );
			}
		}
		else
		{
			printf( "unsupported inputfile %s specified\n", argv[1] );
			system( "pause" );
		}
	}
	else
	{
		printf( "syntax: smd2csm.exe inputfile.<csm|smd>\n" );
		system( "pause" );
	}

	return 0;
}